@@ -56,7 +56,7 @@ async fn test_post_transaction() -> Result<(), Error> {
     airdrop(&arweave).await?;
     let file_path = PathBuf::from("tests/fixtures/0.png");
     let transaction = arweave
-        .create_transaction_from_file_path(file_path, None, None, (0, 0))
+        .create_transaction_from_file_path(file_path, None, None, (0, 0), true)
         .await?;
 
     let signed_transaction = arweave.sign_transaction(transaction)?;
@@ -272,7 +272,7 @@ async fn test_filter_statuses() -> Result<(), Error> {
     // to fetch their raw statuses from the server.
     let paths_iter = glob("tests/fixtures/[5-9]*.png")?.filter_map(Result::ok);
     let transactions = try_join_all(
-        paths_iter.map(|p| arweave.create_transaction_from_file_path(p, None, None, (0, 0))),
+        paths_iter.map(|p| arweave.create_transaction_from_file_path(p, None, None, (0, 0), true)),
     )
     .await?;
     let _ = try_join_all(
